@@ -9,8 +9,11 @@ sub new {
     my ($class, $params) = @_;
     return Ubic::Service::SimpleDaemon->new({
         bin => "echo 'abc' >>tfiles/$params->{name}.result; sleep 10",
-        user => $params->{user},
-        ($params->{group} ? (group => $params->{group}) : ()),
+        (
+            map {
+                defined($params->{$_}) ? ($_ => $params->{$_}) : ()
+            } qw/ user group daemon_user daemon_group /
+        ),
         stdout => "tfiles/$params->{name}.log",
         stderr => "tfiles/$params->{name}.err.log",
         ubic_log => "tfiles/$params->{name}.ubic.log",
